==> ejc-hrmanage-impl-3.0.0-20240614.030401-55-sources.jar: com/ejianc/business/hr/service/impl/BaseUserServiceImpl.java <==
package com.ejianc.business.hr.service.impl;

import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;

import com.ejianc.business.hr.vo.*;
import com.ejianc.framework.skeleton.template.BaseServiceImpl;
import com.ejianc.business.hr.bean.BaseUserEntity;
import com.ejianc.business.hr.mapper.BaseUserMapper;
import com.ejianc.business.hr.service.IBaseUserService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.*;
import java.util.concurrent.ConcurrentHashMap;
import java.util.function.Function;
import java.util.function.Predicate;
import java.util.stream.Collectors;

/**
 * 人力基础人员信息
 *
 * @author generator
 */
@Service("baseUserService")
public class BaseUserServiceImpl extends BaseServiceImpl<BaseUserMapper, BaseUserEntity> implements IBaseUserService {

    @Autowired
    private BaseUserMapper baseUserMapper;

    @Override
    public List<HrOrgVO> queryHrOrgData(String orgCode) {

        return baseUserMapper.queryHrOrgData(orgCode);
    }


    @Override
    public List<UserDataVO> queryAllUserData(Page<UserDataVO> page, QueryWrapper wrapper) {
        return baseUserMapper.queryAllUserData(page, wrapper);
    }

    @Override
    public List<RegisterTypeDataVO> queryRegisterReport(Page<RegisterTypeDataVO> page, QueryWrapper wrapper) {
        return baseUserMapper.queryRegisterReport(page, wrapper);
    }

    @Override
    public List<ResidencyUserDataVO> queryResidencyUserData(Page<ResidencyUserDataVO> page, QueryWrapper wrapper) {
        return baseUserMapper.queryResidencyUserData(page, wrapper);
    }

    @Override
    public List<ResidencyUserDataVO> queryUserChangeData(Page<ResidencyUserDataVO> page, QueryWrapper wrapper) {
        return baseUserMapper.queryUserChangeData(page, wrapper);
    }

    @Override
    public List<TypeVO> querySexType(List<String> orgCodes) {

        List<TypeVO> typeVOS = baseUserMapper.querySexType(orgCodes);
        for (TypeVO typeVO : typeVOS) {
            if (StrUtil.isNotBlank(typeVO.getType())) {
                if (typeVO.getType().equals("1")) {
                    typeVO.setType("男");
                }
                if (typeVO.getType().equals("2")) {
                    typeVO.setType("女");
                }
            }
        }

        return typeVOS;
    }

    @Override
    public List<TypeVO> queryWorkYearType(List<String> orgCodes) {
        List<TypeVO> typeVOS = baseUserMapper.queryWorkYearType(orgCodes);
        for (TypeVO typeVO : typeVOS) {
            if (StrUtil.isNotBlank(typeVO.getType())) {
                switch (typeVO.getType()) {
                    case "1":
                        typeVO.setType("1年");
                        break;
                    case "2":
                        typeVO.setType("1-3年");
                        break;
                    case "3":
                        typeVO.setType("3-5年");
                        break;
                    case "4":
                        typeVO.setType("5-10年");
                        break;
                    case "5":
                        typeVO.setType("10-15年");
                        break;
                    case "6":
                        typeVO.setType("15年以上");
                        break;
                }
            }
        }
        return typeVOS;
    }

    @Override
    public List<TypeVO> queryAgeType(List<String> orgCodes) {
        List<TypeVO> typeVOS = baseUserMapper.queryAgeType(orgCodes);
        for (TypeVO typeVO : typeVOS) {
            if (StrUtil.isNotBlank(typeVO.getType())) {
                switch (typeVO.getType()) {
                    case "1":
                        typeVO.setType("25岁以下");
                        break;
                    case "2":
                        typeVO.setType("25-35岁");
                        break;
                    case "3":
                        typeVO.setType("35-45岁");
                        break;
                    case "4":
                        typeVO.setType("45-55岁");
                        break;
                    case "5":
                        typeVO.setType("55岁以上");
                        break;
                }
            }
        }
        return typeVOS;
    }

    @Override
    public List<TypeVO> queryEductionType(List<String> orgCodes) {

        return baseUserMapper.queryEductionType(orgCodes);
    }

    @Override
    public List<TypeVO> queryZcType(List<String> orgCodes) {

        return baseUserMapper.queryZcType(orgCodes);
    }

    @Override
    public List<TypeVO> queryRegisterType(List<String> orgCodes, List<String> typeCodes) {
        List<TypeVO> typeVOS = baseUserMapper.queryRegisterType(orgCodes, typeCodes);
        for (TypeVO typeVO : typeVOS) {
            if (StrUtil.isNotBlank(typeVO.getTypeCode())) {
                switch (typeVO.getTypeCode()) {
                    case "01":
                        typeVO.setType("注册一级设计师");
                        break;
                    case "05":
                        typeVO.setType("注册会计师");
                        break;
                    case "09":
                        typeVO.setType("注册一级建造师");
                        break;
                    case "14":
                        typeVO.setType("注册二级建造师");
                        break;
                    case "15":
                        typeVO.setType("注册安全工程师");
                        break;
                    case "16":
                        typeVO.setType("注册造价工程师");
                        break;
                    case "17":
                        typeVO.setType("注册监理工程师");
                        break;
                    case "99":
                        typeVO.setType("其他");
                        break;
                }
            }
        }
        return typeVOS;
    }

    @Override
    public List<TypeVO> queryRegisterTypeDetail(List<String> orgCodes, String registerType) {
        return baseUserMapper.queryRegisterTypeDetail(orgCodes, registerType);
    }

    @Override
    public List<TypeVO> queryUserLevel(List<String> orgCodes, List<String> typeCodes) {
        return baseUserMapper.queryUserLevel(orgCodes, typeCodes);
    }

    @Override
    public List<TypeVO> queryOrgType(Page<TypeVO> page, QueryWrapper wrapper) {
        return baseUserMapper.queryOrgType(page, wrapper);
    }

    @Override
    public List<TypeVO> queryUserChange(List<String> orgCodes, String typeCode, Integer year, Integer month) {
        return baseUserMapper.queryUserChange(orgCodes, typeCode, year, month);
    }

    @Override
    public List<TypeVO> queryUserChangeLz(List<String> orgCodes, String typeCode, Integer year, Integer month) {
        return baseUserMapper.queryUserChangeLz(orgCodes, typeCode, year, month);
    }

    @Override
    public List<TypeVO> queryMnyChange(List<String> orgCodes) {
        return baseUserMapper.queryMnyChange(orgCodes);
    }

    @Override
    public List<UserMnyDetailVO> queryUserMnyDetail(Page<UserMnyDetailVO> page, QueryWrapper wrapper) {
        return baseUserMapper.queryUserMnyDetail(page, wrapper);
    }

    @Override
    public List<UserMnyDetailVO> queryUserMnyData(Page<UserMnyDetailVO> page, QueryWrapper wrapper) {
        return baseUserMapper.queryUserMnyData(page, wrapper);
    }

    @Override
    public List<UnderReportVO> queryUnderReport(Page<UnderReportVO> page, QueryWrapper wrapper) {
        return baseUserMapper.queryUnderReport(page, wrapper);
    }

    @Override
    public List<UnderReportVO> queryOrgUnder(Page<UnderReportVO> page, QueryWrapper wrapper) {
        return baseUserMapper.queryOrgUnder(page, wrapper);
    }

    @Override
    public List<TypeVO> queryUserType(Page<TypeVO> page, QueryWrapper wrapper) {
        return baseUserMapper.queryUserType(page, wrapper);
    }

    @Override
    public List<UnderReportVO> queryOrgUnderNum(Page<UnderReportVO> page, QueryWrapper wrapper) {
        return baseUserMapper.queryOrgUnderNum(page, wrapper);
    }

    @Override
    public List<OrgPayReportVO> queryOrgPayReport(Page<OrgPayReportVO> page, QueryWrapper wrapper) {
        return baseUserMapper.queryOrgPayReport(page, wrapper);
    }

    @Override
    public List<JobLevelVO> queryJobLevelReport(Page<JobLevelVO> page, QueryWrapper wrapper) {
        List<JobLevelVO> baseVOS = baseUserMapper.queryJobLevelReport(page, wrapper);
        ArrayList<JobLevelVO> resultVOS = new ArrayList<>();
        //将无岗级的放在其他里
        List<JobLevelVO> handleVOS = baseVOS.stream().map(s -> {
            if (s.getJobLevelCode() == null) {
                s.setJobLevelCode("0");
                s.setJobLevelName("其他");
            }
            return s;
        }).collect(Collectors.toList());
        //获取去重后固定岗级的的list
        TreeSet<JobLevelVO> distinctVOS = new TreeSet<>(Comparator.comparing(JobLevelVO::getJobLevelCode));
        distinctVOS.addAll(handleVOS);
        for (JobLevelVO handleVO : distinctVOS) {
            for (JobLevelVO baseVO : baseVOS) {
                if (handleVO.getJobLevelCode() != null) {
                    if (handleVO.getJobLevelCode().equals(baseVO.getJobLevelCode())) {
                        if (baseVO.getPostCode() != null) {
                            switch (baseVO.getPostCode()) {
                                case "101":
                                    handleVO.setPostCode1(baseVO.getValue());
                                    break;
                                case "102":
                                    handleVO.setPostCode2(baseVO.getValue());
                                    break;
                                case "103":
                                    handleVO.setPostCode3(baseVO.getValue());
                                    break;
                                case "104":
                                    handleVO.setPostCode4(baseVO.getValue());
                                    break;
                                case "105":
                                    handleVO.setPostCode5(baseVO.getValue());
                                    break;
                                case "106":
                                    handleVO.setPostCode6(baseVO.getValue());
                                    break;
                                case "107":
                                    handleVO.setPostCode7(baseVO.getValue());
                                    break;
                                case "108":
                                    handleVO.setPostCode8(baseVO.getValue());
                                    break;
                                case "109":
                                    handleVO.setPostCode9(baseVO.getValue());
                                    break;
                                case "110":
                                    handleVO.setPostCode10(baseVO.getValue());
                                    break;
                                case "111":
                                    handleVO.setPostCode11(baseVO.getValue());
                                    break;
                                case "112":
                                    handleVO.setPostCode12(baseVO.getValue());
                                    break;
                                case "113":
                                    handleVO.setPostCode13(baseVO.getValue());
                                    break;
                                case "114":
                                    handleVO.setPostCode14(baseVO.getValue());
                                    break;
                                case "115":
                                    handleVO.setPostCode15(baseVO.getValue());
                                    break;
                                default:
                                    break;
                            }
                        } else {
                            handleVO.setPostCodeOther(baseVO.getValue());
                        }


                    }
                } else {
                    if (handleVO.getJobLevelCode().equals("0")) {
                        if (baseVO.getPostCode() != null) {
                            switch (baseVO.getPostCode()) {
                                case "101":
                                    handleVO.setPostCode1(baseVO.getValue());
                                    break;
                                case "102":
                                    handleVO.setPostCode2(baseVO.getValue());
                                    break;
                                case "103":
                                    handleVO.setPostCode3(baseVO.getValue());
                                    break;
                                case "104":
                                    handleVO.setPostCode4(baseVO.getValue());
                                    break;
                                case "105":
                                    handleVO.setPostCode5(baseVO.getValue());
                                    break;
                                case "106":
                                    handleVO.setPostCode6(baseVO.getValue());
                                    break;
                                case "107":
                                    handleVO.setPostCode7(baseVO.getValue());
                                    break;
                                case "108":
                                    handleVO.setPostCode8(baseVO.getValue());
                                    break;
                                case "109":
                                    handleVO.setPostCode9(baseVO.getValue());
                                    break;
                                case "110":
                                    handleVO.setPostCode10(baseVO.getValue());
                                    break;
                                case "111":
                                    handleVO.setPostCode11(baseVO.getValue());
                                    break;
                                case "112":
                                    handleVO.setPostCode12(baseVO.getValue());
                                    break;
                                case "113":
                                    handleVO.setPostCode13(baseVO.getValue());
                                    break;
                                case "114":
                                    handleVO.setPostCode14(baseVO.getValue());
                                    break;
                                case "115":
                                    handleVO.setPostCode15(baseVO.getValue());
                                    break;
                                default:
                                    break;
                            }
                        } else {
                            handleVO.setPostCodeOther(baseVO.getValue());
                        }

                    }
                }
            }
        }


        return new ArrayList<>(distinctVOS);
    }
}

==> ejc-hrmanage-impl-3.0.0-20240617.093247-62-sources.jar: com/ejianc/business/hr/service/impl/BaseUserServiceImpl.java <==
package com.ejianc.business.hr.service.impl;

import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;

import com.ejianc.business.hr.vo.*;
import com.ejianc.framework.skeleton.template.BaseServiceImpl;
import com.ejianc.business.hr.bean.BaseUserEntity;
import com.ejianc.business.hr.mapper.BaseUserMapper;
import com.ejianc.business.hr.service.IBaseUserService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.*;
import java.util.concurrent.ConcurrentHashMap;
import java.util.function.Function;
import java.util.function.Predicate;
import java.util.stream.Collectors;

/**
 * 人力基础人员信息
 *
 * @author generator
 */
@Service("baseUserService")
public class BaseUserServiceImpl extends BaseServiceImpl<BaseUserMapper, BaseUserEntity> implements IBaseUserService {

    @Autowired
    private BaseUserMapper baseUserMapper;

    @Override
    public List<HrOrgVO> queryHrOrgData(String orgCode) {

        return baseUserMapper.queryHrOrgData(orgCode);
    }


    @Override
    public List<UserDataVO> queryAllUserData(Page<UserDataVO> page, QueryWrapper wrapper) {
        return baseUserMapper.queryAllUserData(page, wrapper);
    }

    @Override
    public List<RegisterTypeDataVO> queryRegisterReport(Page<RegisterTypeDataVO> page, QueryWrapper wrapper) {
        return baseUserMapper.queryRegisterReport(page, wrapper);
    }

    @Override
    public List<ResidencyUserDataVO> queryResidencyUserData(Page<ResidencyUserDataVO> page, QueryWrapper wrapper) {
        return baseUserMapper.queryResidencyUserData(page, wrapper);
    }

    @Override
    public List<ResidencyUserDataVO> queryUserChangeData(Page<ResidencyUserDataVO> page, QueryWrapper wrapper) {
        return baseUserMapper.queryUserChangeData(page, wrapper);
    }

    @Override
    public List<TypeVO> querySexType(List<String> orgCodes) {

        List<TypeVO> typeVOS = baseUserMapper.querySexType(orgCodes);
        for (TypeVO typeVO : typeVOS) {
            if (StrUtil.isNotBlank(typeVO.getType())) {
                if (typeVO.getType().equals("1")) {
                    typeVO.setType("男");
                }
                if (typeVO.getType().equals("2")) {
                    typeVO.setType("女");
                }
            }
        }

        return typeVOS;
    }

    @Override
    public List<TypeVO> queryWorkYearType(List<String> orgCodes) {
        List<TypeVO> typeVOS = baseUserMapper.queryWorkYearType(orgCodes);
        for (TypeVO typeVO : typeVOS) {
            if (StrUtil.isNotBlank(typeVO.getType())) {
                switch (typeVO.getType()) {
                    case "1":
                        typeVO.setType("1年");
                        break;
                    case "2":
                        typeVO.setType("1-3年");
                        break;
                    case "3":
                        typeVO.setType("3-5年");
                        break;
                    case "4":
                        typeVO.setType("5-10年");
                        break;
                    case "5":
                        typeVO.setType("10-15年");
                        break;
                    case "6":
                        typeVO.setType("15年以上");
                        break;
                }
            }
        }
        return typeVOS;
    }

    @Override
    public List<TypeVO> queryAgeType(List<String> orgCodes) {
        List<TypeVO> typeVOS = baseUserMapper.queryAgeType(orgCodes);
        for (TypeVO typeVO : typeVOS) {
            if (StrUtil.isNotBlank(typeVO.getType())) {
                switch (typeVO.getType()) {
                    case "1":
                        typeVO.setType("25岁以下");
                        break;
                    case "2":
                        typeVO.setType("25-35岁");
                        break;
                    case "3":
                        typeVO.setType("35-45岁");
                        break;
                    case "4":
                        typeVO.setType("45-55岁");
                        break;
                    case "5":
                        typeVO.setType("55岁以上");
                        break;
                }
            }
        }
        return typeVOS;
    }

    @Override
    public List<TypeVO> queryEductionType(List<String> orgCodes) {

        return baseUserMapper.queryEductionType(orgCodes);
    }

    @Override
    public List<TypeVO> queryZcType(List<String> orgCodes) {

        return baseUserMapper.queryZcType(orgCodes);
    }

    @Override
    public List<TypeVO> queryRegisterType(List<String> orgCodes, List<String> typeCodes) {
        List<TypeVO> typeVOS = baseUserMapper.queryRegisterType(orgCodes, typeCodes);
        for (TypeVO typeVO : typeVOS) {
            if (StrUtil.isNotBlank(typeVO.getTypeCode())) {
                switch (typeVO.getTypeCode()) {
                    case "01":
                        typeVO.setType("注册一级设计师");
                        break;
                    case "05":
                        typeVO.setType("注册会计师");
                        break;
                    case "09":
                        typeVO.setType("注册一级建造师");
                        break;
                    case "14":
                        typeVO.setType("注册二级建造师");
                        break;
                    case "15":
                        typeVO.setType("注册安全工程师");
                        break;
                    case "16":
                        typeVO.setType("注册造价工程师");
                        break;
                    case "17":
                        typeVO.setType("注册监理工程师");
                        break;
                    case "99":
                        typeVO.setType("其他");
                        break;
                }
            }
        }
        return typeVOS;
    }

    @Override
    public List<TypeVO> queryRegisterTypeDetail(List<String> orgCodes, String registerType) {
        return baseUserMapper.queryRegisterTypeDetail(orgCodes, registerType);
    }

    @Override
    public List<TypeVO> queryUserLevel(List<String> orgCodes, List<String> typeCodes) {
        return baseUserMapper.queryUserLevel(orgCodes, typeCodes);
    }

    @Override
    public List<TypeVO> queryOrgType(Page<TypeVO> page, QueryWrapper wrapper) {
        return baseUserMapper.queryOrgType(page, wrapper);
    }

    @Override
    public List<TypeVO> queryUserChange(List<String> orgCodes, String typeCode, Integer year, Integer month) {
        return baseUserMapper.queryUserChange(orgCodes, typeCode, year, month);
    }

    @Override
    public List<TypeVO> queryUserChangeLz(List<String> orgCodes, String typeCode, Integer year, Integer month) {
        return baseUserMapper.queryUserChangeLz(orgCodes, typeCode, year, month);
    }

    @Override
    public List<TypeVO> queryMnyChange(List<String> orgCodes) {
        return baseUserMapper.queryMnyChange(orgCodes);
    }

    @Override
    public List<UserMnyDetailVO> queryUserMnyDetail(Page<UserMnyDetailVO> page, QueryWrapper wrapper) {
        return baseUserMapper.queryUserMnyDetail(page, wrapper);
    }

    @Override
    public List<UserMnyDetailVO> queryUserMnyData(Page<UserMnyDetailVO> page, QueryWrapper wrapper) {
        return baseUserMapper.queryUserMnyData(page, wrapper);
    }

    @Override
    public List<UnderReportVO> queryUnderReport(Page<UnderReportVO> page, QueryWrapper wrapper) {
        return baseUserMapper.queryUnderReport(page, wrapper);
    }

    @Override
    public List<UnderReportVO> queryOrgUnder(Page<UnderReportVO> page, QueryWrapper wrapper) {
        return baseUserMapper.queryOrgUnder(page, wrapper);
    }

    @Override
    public List<TypeVO> queryUserType(Page<TypeVO> page, QueryWrapper wrapper) {
        return baseUserMapper.queryUserType(page, wrapper);
    }

    @Override
    public List<UnderReportVO> queryOrgUnderNum(Page<UnderReportVO> page, QueryWrapper wrapper) {
        return baseUserMapper.queryOrgUnderNum(page, wrapper);
    }

    @Override
    public List<OrgPayReportVO> queryOrgPayReport(Page<OrgPayReportVO> page, QueryWrapper wrapper) {
        return baseUserMapper.queryOrgPayReport(page, wrapper);
    }

    @Override
    public List<JobLevelVO> queryJobLevelReport(Page<JobLevelVO> page, QueryWrapper wrapper) {
        List<JobLevelVO> baseVOS = baseUserMapper.queryJobLevelReport(page, wrapper);
        ArrayList<JobLevelVO> resultVOS = new ArrayList<>();
        //将无岗级的放在其他里
        List<JobLevelVO> handleVOS = baseVOS.stream().map(s -> {
            if (s.getJobLevelCode() == null) {
                s.setJobLevelCode("0");
                s.setJobLevelName("其他");
            }
            return s;
        }).collect(Collectors.toList());
        //获取去重后固定岗级的的list
        TreeSet<JobLevelVO> distinctVOS = new TreeSet<>(Comparator.comparing(JobLevelVO::getJobLevelCode));
        distinctVOS.addAll(handleVOS);
        for (JobLevelVO handleVO : distinctVOS) {
            for (JobLevelVO baseVO : baseVOS) {
                if (handleVO.getJobLevelCode() != null) {
                    if (handleVO.getJobLevelCode().equals(baseVO.getJobLevelCode())) {
                        if (baseVO.getPostCode() != null) {
                            switch (baseVO.getPostCode()) {
                                case "101":
                                    handleVO.setPostCode1(baseVO.getValue());
                                    break;
                                case "102":
                                    handleVO.setPostCode2(baseVO.getValue());
                                    break;
                                case "103":
                                    handleVO.setPostCode3(baseVO.getValue());
                                    break;
                                case "104":
                                    handleVO.setPostCode4(baseVO.getValue());
                                    break;
                                case "105":
                                    handleVO.setPostCode5(baseVO.getValue());
                                    break;
                                case "106":
                                    handleVO.setPostCode6(baseVO.getValue());
                                    break;
                                case "107":
                                    handleVO.setPostCode7(baseVO.getValue());
                                    break;
                                case "108":
                                    handleVO.setPostCode8(baseVO.getValue());
                                    break;
                                case "109":
                                    handleVO.setPostCode9(baseVO.getValue());
                                    break;
                                case "110":
                                    handleVO.setPostCode10(baseVO.getValue());
                                    break;
                                case "111":
                                    handleVO.setPostCode11(baseVO.getValue());
                                    break;
                                case "112":
                                    handleVO.setPostCode12(baseVO.getValue());
                                    break;
                                case "113":
                                    handleVO.setPostCode13(baseVO.getValue());
                                    break;
                                case "114":
                                    handleVO.setPostCode14(baseVO.getValue());
                                    break;
                                case "115":
                                    handleVO.setPostCode15(baseVO.getValue());
                                    break;
                                default:
                                    break;
                            }
                        } else {
                            handleVO.setPostCodeOther(baseVO.getValue());
                        }


                    }
                } else {
                    if (handleVO.getJobLevelCode().equals("0")) {
                        if (baseVO.getPostCode() != null) {
                            switch (baseVO.getPostCode()) {
                                case "101":
                                    handleVO.setPostCode1(baseVO.getValue());
                                    break;
                                case "102":
                                    handleVO.setPostCode2(baseVO.getValue());
                                    break;
                                case "103":
                                    handleVO.setPostCode3(baseVO.getValue());
                                    break;
                                case "104":
                                    handleVO.setPostCode4(baseVO.getValue());
                                    break;
                                case "105":
                                    handleVO.setPostCode5(baseVO.getValue());
                                    break;
                                case "106":
                                    handleVO.setPostCode6(baseVO.getValue());
                                    break;
                                case "107":
                                    handleVO.setPostCode7(baseVO.getValue());
                                    break;
                                case "108":
                                    handleVO.setPostCode8(baseVO.getValue());
                                    break;
                                case "109":
                                    handleVO.setPostCode9(baseVO.getValue());
                                    break;
                                case "110":
                                    handleVO.setPostCode10(baseVO.getValue());
                                    break;
                                case "111":
                                    handleVO.setPostCode11(baseVO.getValue());
                                    break;
                                case "112":
                                    handleVO.setPostCode12(baseVO.getValue());
                                    break;
                                case "113":
                                    handleVO.setPostCode13(baseVO.getValue());
                                    break;
                                case "114":
                                    handleVO.setPostCode14(baseVO.getValue());
                                    break;
                                case "115":
                                    handleVO.setPostCode15(baseVO.getValue());
                                    break;
                                default:
                                    break;
                            }
                        } else {
                            handleVO.setPostCodeOther(baseVO.getValue());
                        }

                    }
                }
            }
        }


        return new ArrayList<>(distinctVOS);
    }

    @Override
    public List<SalaryDetailVO> querySalaryDetail(Page<SalaryDetailVO> page, QueryWrapper wrapper) {
        return baseUserMapper.querySalaryDetail(page, wrapper);
    }

//    @Override
//    public List<TypeVO> queryTrainTop(String startDate, String endDate) {
//        return baseUserMapper.queryTrainTop(startDate, endDate);
//    }
    @Override
    public List<TypeVO> queryTrainTop(Page<TypeVO> page, QueryWrapper wrapper) {
        return baseUserMapper.queryTrainTop(page, wrapper);
    }

    @Override
    public List<ProjectEmployeeVO> queryEmployeeReport(Page<ProjectEmployeeVO> page, QueryWrapper wrapper) {
        return baseUserMapper.queryEmployeeReport(page,wrapper);
    }
}
